@@ -8,7 +8,7 @@ use strict;
 
 package Log::Report::Lexicon::POT;
 use vars '$VERSION';
-$VERSION = '0.97';
+$VERSION = '0.98';
 
 
 use Log::Report 'log-report', syntax => 'SHORT';
@@ -20,6 +20,8 @@ use POSIX       qw/strftime/;
 use IO::File;
 use List::Util  qw/sum/;
 
+use constant    MSGID_HEADER => '';
+
 
 sub new(@)
 {   my $class = shift;
@@ -66,13 +68,16 @@ sub read($@)
         or fault __x"cannot read in {cs} from file {fn}"
              , cs => $charset, fn => $fn;
 
-    local $/ = "\n\n";
+    local $/   = "\n\n";
+    my $linenr = 1;  # $/ frustrates $fh->input_line_number
     while(1)
-    {   my $location = "$fn line ".$fh->input_line_number;
+    {   my $location = "$fn line $linenr";
         my $block    = <$fh>;
         defined $block or last;
 
-        $block =~ s/\s+\z//s;
+        $linenr += $block =~ tr/\n//;
+
+        $block   =~ s/\s+\z//s;
         length $block or last;
 
         my $po = Log::Report::Lexicon::PO->fromText($block, $location);
@@ -106,10 +111,10 @@ sub write($@)
                     , fn => $file, layers => $layers;
     }
 
-    $fh->print($self->msgid("")->toString(@opt));
+    $fh->print($self->msgid(MSGID_HEADER)->toString(@opt));
     my $index = $self->index;
     foreach my $msgid (sort keys %$index)
-    {   next if $msgid eq '';
+    {   next if $msgid eq MSGID_HEADER;
 
         my $po = $index->{$msgid};
         next if $po->unused;
@@ -181,7 +186,7 @@ sub _now() { strftime "%Y-%m-%d %H:%M%z", localtime }
 
 sub header($;$)
 {   my ($self, $field) = (shift, shift);
-    my $header = $self->msgid('')
+    my $header = $self->msgid(MSGID_HEADER)
         or error __x"no header defined in POT for file {fn}"
                    , fn => $self->filename;
 
@@ -221,7 +226,7 @@ sub _createHeader(%)
     my $date   = $args{date} || _now;
 
     my $header = Log::Report::Lexicon::PO->new
-     (  msgid  => '', msgstr => <<__CONFIG);
+     (  msgid  => MSGID_HEADER, msgstr => <<__CONFIG);
 Project-Id-Version: $args{project}
 Report-Msgid-Bugs-To:
 POT-Creation-Date: $date
@@ -237,7 +242,7 @@ __CONFIG
     my $version = $Log::Report::VERSION || '0.0';
     $header->addAutomatic("Header generated with ".__PACKAGE__." $version\n");
 
-    $self->index->{''} = $header
+    $self->index->{&MSGID_HEADER} = $header
         if $header;
 
     $header;
@@ -254,7 +259,7 @@ sub stats()
 {   my $self  = shift;
     my %stats = (msgids => 0, fuzzy => 0, inactive => 0);
     foreach my $po ($self->translations)
-    {   next if $po->msgid eq '';
+    {   next if $po->msgid eq MSGID_HEADER;
         $stats{msgids}++;
         $stats{fuzzy}++    if $po->fuzzy;
         $stats{inactive}++ if !$po->isActive && !$po->unused;
